Domain
=================

.. autoclass:: shephard.domain.Domain


Domain Properties
...................
.. autofunction:: shephard.domain.Domain.start
.. autofunction:: shephard.domain.Domain.end
.. autofunction:: shephard.domain.Domain.protein
.. autofunction:: shephard.domain.Domain.sequence
.. autofunction:: shephard.domain.Domain.domain_type

Domain Functions
.................
.. autofunction:: shephard.domain.Domain.inside_domain


Domain Attribute Functions
...........................
.. autofunction:: shephard.domain.Domain.attributes
.. autofunction:: shephard.domain.Domain.attribute
.. autofunction:: shephard.domain.Domain.add_attribute
.. autofunction:: shephard.domain.Domain.remove_attribute


Domain Site Functions
...........................
.. autofunction:: shephard.domain.Domain.sites
.. autofunction:: shephard.domain.Domain.site
.. autofunction:: shephard.domain.Domain.get_sites_by_type


Domain Track Functions
...........................
.. autofunction:: shephard.domain.Domain.get_track_values
.. autofunction:: shephard.domain.Domain.get_track_symbols
